==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/Experiments/ExperimentImplementation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  ExperimentImplementation.cxx
 *  @brief Abstract top-level view of an experimentImplementation plane
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *  Id:      $Id: ExperimentImplementation.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "OT.hxx"
#include "ExperimentImplementation.hxx"
#include "Exception.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      typedef Base::Common::NotYetImplementedException NotYetImplementedException;

      CLASSNAMEINIT(ExperimentImplementation);

      /* Default constructor */
      ExperimentImplementation::ExperimentImplementation(const String & name):
	PersistentObject(name),
	center_(NumericalPoint(0)),
	levels_(NumericalPoint(0))
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      ExperimentImplementation::ExperimentImplementation(const NumericalPoint & center,
							 const NumericalPoint & levels,
							 const String & name):
	PersistentObject(name),
	center_(center),
	levels_(levels)
      {
	// Nothing to do
      }

      /* String converter */
      String ExperimentImplementation::str() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName ()
	    << " center=" << center_
	    << " levels=" << levels_;
	return oss;
      }

      /* Center accessor */
      void ExperimentImplementation::setCenter(const NumericalPoint & center)
      {
	center_ = center;
      }

      /* Center accessor */
      ExperimentImplementation::NumericalPoint ExperimentImplementation::getCenter() const
      {
	return center_;
      }

      /* Levels accessor */
      void ExperimentImplementation::setLevels(const NumericalPoint & levels)
      {
	levels_ = levels;
      }

      /* Levels accessor */
      ExperimentImplementation::NumericalPoint ExperimentImplementation::getLevels() const
      {
	return levels_;
      }

      /* Sample generation */
      ExperimentImplementation::NumericalSample ExperimentImplementation::generate()
      {
	throw NotYetImplementedException(HERE);
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Algorithm/Experiments/ExperimentImplementation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  ExperimentImplementation.cxx
 *  @brief Abstract top-level view of an experiment plane
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: ExperimentImplementation.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "OTprivate.hxx"
#include "ExperimentImplementation.hxx"
#include "Exception.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      typedef Base::Common::NotYetImplementedException NotYetImplementedException;

      CLASSNAMEINIT(ExperimentImplementation);

      /* Default constructor */
      ExperimentImplementation::ExperimentImplementation(const String & name):
	PersistentObject(name)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      ExperimentImplementation * ExperimentImplementation::clone() const
      {
	return new ExperimentImplementation(*this);
      }

      /* String converter */
      String ExperimentImplementation::__repr__() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName();
	return oss;
      }

      /* Sample generation */
      ExperimentImplementation::NumericalSample ExperimentImplementation::generate()
      {
	throw NotYetImplementedException(HERE);
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
